@@ -199,10 +199,10 @@ class SenseMapClient(ReprObject):
             try:
                 return decorated_function(self, *args, **kwargs)
             except OpenSenseMapAPITooManyRequestsError as e:
-                logger.debug(e)
+                logger.error(f"API says too many requests: {e}")
                 m = re.search(
-                    pattern=r"(?:(?P<seconds>\d+\.\d+)\s*s)|"
-                    r"(?:(?P<milliseconds>\d+\.\d+)\s*ms)",
+                    pattern=r"(?:(?P<seconds>\d+(?:\.\d+)?)\s*s?)|"
+                    r"(?:(?P<milliseconds>\d+(?:\.\d+)?)\s*ms)",
                     string=str(e),
                 )
                 try:
@@ -214,10 +214,13 @@ class SenseMapClient(ReprObject):
                         retry_after_seconds += float(seconds)
                     if milliseconds:
                         retry_after_seconds += float(milliseconds) / 1000
-                except (AttributeError, ValueError, KeyError, IndexError):
-                    raise OpenSenseMapAPITooManyRequestsError(
-                        "Could not determine " "time to wait until next retry."
+                except (AttributeError, ValueError, KeyError, IndexError) as e:
+                    logger.error(
+                        f"Could not determine time to wait until next retry. "
+                        f"({type(e).__name__}: {e}). "
+                        f"Waiting 5 seconds."
                     )
+                    retry_after_seconds = 5
                 logger.debug(
                     "Waiting {} seconds until retry...".format(
                         retry_after_seconds
