@@ -59,7 +59,7 @@ class ReprObject(object):  # pragma: no cover
     def to_json_fallback(self, x):
         try:
             return x.to_json()
-        except (AttributeError):
+        except AttributeError:
             return str(x)
 
     def to_json(self):
